﻿namespace XtraReportSerialization {
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using Soneta.Business;
    using Soneta.Handel;
    using Soneta.Langs;
    using Soneta.Magazyny;
    using Soneta.Towary;
    using Soneta.Types;
    using Soneta.Tools;
    using DevExpress.XtraReports.UI;
    
    public class OCWgTow : DevExpress.XtraReports.UI.XtraReport {

        // Report Script Start
        public interface IDokumentPozycjaTowaru
        {
            int Id { get; set; }
            string Nazwa { get; set; }
            string Kod { get; set; }
            Quantity Ilość { get; set; }
            Currency OCjednostkowa { get; set; }
            Currency WartoscOC { get; set; }
            void Add(PozycjaDokHandlowego poz, Session s);
                void _Finalize();
        }
        
        public class PozycjaTowaru : IDokumentPozycjaTowaru
        {
            public int Id { get; set; }
            public string Nazwa { get; set; }
            public string Kod { get; set; }
            public Quantity Ilość { get; set; }
            public Currency OCjednostkowa { get; set; }
            public Currency WartoscOC { get; set; }
        
            private List<PozycjaDokHandlowego> wliczonePozycje = new List<PozycjaDokHandlowego>();
        
            public PozycjaTowaru(PozycjaDokHandlowego pozycja, Session s)
            {    
                    var Oplata = Soneta
                    .OplataCukrowa
                    .OplataCukrowaModule.GetInstance(s)
                    .OpCukrPozDok
                    .GetOplataCukrowaPozycjaDokHandlowego(pozycja, false)
                    .Oplata;
                    
                        WartoscOC = Oplata;
                wliczonePozycje.Add(pozycja);
                Nazwa = pozycja.NazwaIndywidualna;
                Kod = pozycja.Towar.Kod;
                Ilość = pozycja.ZmianaIlościMagazynu;
            }
        
            public void Add(PozycjaDokHandlowego pozycja, Session s)
            {
                if (!wliczonePozycje.Any(x => x.ID == pozycja.ID))
                {
                     var Oplata = Soneta
                    .OplataCukrowa
                    .OplataCukrowaModule.GetInstance(s)
                    .OpCukrPozDok
                    .GetOplataCukrowaPozycjaDokHandlowego(pozycja, false)
                    .Oplata;
                    WartoscOC += Oplata;
                    Ilość += pozycja.ZmianaIlościMagazynu;
                    wliczonePozycje.Add(pozycja);
                }
            }
            
              public void _Finalize()
                {
                    OCjednostkowa = new Currency(WartoscOC.Value/((decimal)Ilość.Value), WartoscOC.Symbol);
                }
            
            public override string ToString() { return Nazwa; }
        }
        public class ParametryContext : ContextBase
        {
            private List<IDokumentPozycjaTowaru> _Kontener = new List<IDokumentPozycjaTowaru>();
        
            public ParametryContext(Context cx)
                   : base(cx)
            {
                Row[] doks;
                cx.Get(out doks);
        
                FillContainer(converter(doks), cx.Session);               
            }
        
            DokumentHandlowy[] converter(Row[] rows)
            {
                DokumentHandlowy[] _doks = new DokumentHandlowy[rows.Length];
                for (int i = 0; i < _doks.Length; i++)
                {
                    _doks[i] = (DokumentHandlowy)rows[i];
                }
        
                return _doks;
            }
        
            public void FillContainer(DokumentHandlowy[] doks, Session s)
            {
                var _doks = doks.Where(x => 
                                                                        x.Stan != StanDokumentuHandlowego.Anulowany &&
                                                                        (x.Kategoria == KategoriaHandlowa.Sprzedaż || x.Kategoria == KategoriaHandlowa.KorektaSprzedaży) && 
                                                                        x.Definicja.SumyVAT != SposobLiczeniaSumVAT.LiczyćProporcjonalnie &&
                                                                        x.Definicja.SumyVAT != SposobLiczeniaSumVAT.KorygowanaZaliczka &&
                                                                        x.Definicja.DuplikatWartosci == false &&
                                                                        x.Definicja.KierunekPlatnosci == Soneta.Core.KierunekPlatnosci.Przychod &&
                                                                        x.Definicja.PlanSplat == false &&
                                                                        Soneta.
                                                                        OplataCukrowa.
                                                                        OplataCukrowaModule.
                                                                        GetInstance(s).
                                                                        OpCukrKontrah.
                                                                        GetOplataCukrowaKontrahent(x.Kontrahent, false).
                                                                        NaliczanieOplatyCukrowej != Soneta.OplataCukrowa.NaliczanieOplatyCukrowej.Brak
                    ).ToList();
                foreach (var dok in _doks)
                    foreach (var poz in dok.Pozycje)
                    {
                                    var Oplata = Soneta
                    .OplataCukrowa
                    .OplataCukrowaModule.GetInstance(s)
                    .OpCukrPozDok
                    .GetOplataCukrowaPozycjaDokHandlowego(poz, false)
                    .Oplata;
                                    
                                    if(Oplata.Value == 0)
                                                continue;
                                    
                        if (_Kontener.Where(x => x.Nazwa == poz.Towar.Nazwa).Any())
                        {
                            _Kontener.First(x => x.Nazwa == poz.Towar.Nazwa).Add(poz, s);
                        }
                        else
                        {
                            var _poz = new PozycjaTowaru(poz, s);
                            _poz.Id = _Kontener.Count + 1;
                            _Kontener.Add(_poz);
                        }
                    }
                   
            }
        
            [TranslateIgnore]
            [System.ComponentModel.Browsable(false)]
            public List<IDokumentPozycjaTowaru> Kontener
            {
                get
                {
                    return _Kontener;
                }
            }
        }
        
        [Context(CreateOnly = true)]
        public static ParametryContext Parametry { get; set; }
        
        private void Powiazanie_DataSourceDemanded(object sender, System.EventArgs e)
        {
            this.Powiazanie.DataSource = Parametry.Kontener;
        }
        
        private void SprzedazTowarowIUslugWgPozycji_BeforePrint(object sender, System.Drawing.Printing.PrintEventArgs e)
        {
            Soneta.Business.Context dc = (DataSource as Soneta.Business.UI.DxReports.BusinessDataSource)[0] as Soneta.Business.Context;
            var filters = new List<string>();
            Soneta.Handel.Forms.DokHandloweViewInfo.WParams pars = (Soneta.Handel.Forms.DokHandloweViewInfo.WParams)dc[typeof(Soneta.Handel.Forms.DokHandloweViewInfo.WParams)];
            filters.Add("Odrzucono anulowane, duplikaty i faktury zaliczkowe".Translate());
        
            if (pars.Seria != null)
                filters.Add("Seria: {0}".TranslateFormat(pars.Seria.ToString()));
            if (pars.Magazyn != null)
                filters.Add("Magazyn: {0}".TranslateFormat(pars.Magazyn.ToString()));
            filters.Add("Okres: {0}".TranslateFormat(pars.Okres.ToString()));
            if (pars.Kontrahent != null)
                filters.Add("Kontrahent: {0}".TranslateFormat(pars.Kontrahent.ToString()));
            if (pars.Definicja != null)
                filters.Add("Definicja: {0}".TranslateFormat(pars.Definicja.ToString()));
        
            SzablonNagłówkaStrony.Title = "Opłata cukrowa (wg towarów).".Translate();
            SzablonNagłówkaStrony.FiltersDescription = filters.ToArray();
            
              
        }
        
        private void SumaIlosc_BeforePrint(object sender, System.Drawing.Printing.PrintEventArgs e) {
            bool rozneJednostki = false;
            Quantity suma = Quantity.Empty;
            foreach (var ob in Parametry.Kontener)
            {
                if (suma == Quantity.Empty)
                    suma = new Quantity(0, ob.Ilość.Symbol);
        
                if (suma.Symbol == ob.Ilość.Symbol)
                    suma += ob.Ilość;
                else
                {
                    rozneJednostki = true;
                    break;
                }
        
            }
            if (!rozneJednostki)
                SumaIlosc.Text = suma.ToString();
            else
                SumaIlosc.Text = "Różne jednostki".Translate();
        }
        
        private void SumaWratoscOC_BeforePrint(object sender, System.Drawing.Printing.PrintEventArgs e) {
             Currency suma = new Currency(0.0, "PLN");
            foreach (var ob in Parametry.Kontener)
            {            
                suma += ob.WartoscOC;
            }
            SumaWratoscOC.Text = suma.ToString();
        }
        
        // Report Script End

        private void InitializeEvents() {
            BeforePrint += SprzedazTowarowIUslugWgPozycji_BeforePrint;
            SumaWratoscOC.BeforePrint += SumaWratoscOC_BeforePrint;
            SumaIlosc.BeforePrint += SumaIlosc_BeforePrint;
            Powiazanie.DataSourceDemanded += Powiazanie_DataSourceDemanded;
        }

        #region Report definition

        private DevExpress.XtraReports.UI.TopMarginBand TopMargin;
        private DevExpress.XtraReports.UI.DetailBand Detail;
        private DevExpress.XtraReports.UI.BottomMarginBand BottomMargin;
        private DevExpress.XtraReports.UI.DetailReportBand Powiazanie;
        private DevExpress.XtraReports.UI.DetailBand Detail1;
        private DevExpress.XtraReports.UI.XRTable table1;
        private DevExpress.XtraReports.UI.XRTableRow tableRow1;
        private DevExpress.XtraReports.UI.XRTableCell tableCell6;
        private DevExpress.XtraReports.UI.XRTableCell tableCell7;
        private DevExpress.XtraReports.UI.XRTableCell tableCell1;
        private DevExpress.XtraReports.UI.XRTableCell tableCell2;
        private DevExpress.XtraReports.UI.XRTableCell tableCell5;
        private DevExpress.XtraReports.UI.GroupHeaderBand ListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table2;
        private DevExpress.XtraReports.UI.XRTableRow tableRow2;
        private DevExpress.XtraReports.UI.XRTableCell tableCell8;
        private DevExpress.XtraReports.UI.XRTableCell tableCell9;
        private DevExpress.XtraReports.UI.XRTableCell tableCell14;
        private DevExpress.XtraReports.UI.XRTableRow tableRow4;
        private DevExpress.XtraReports.UI.XRTableCell tableCell19;
        private DevExpress.XtraReports.UI.XRTableCell tableCell20;
        private DevExpress.XtraReports.UI.XRTableCell tableCell21;
        private DevExpress.XtraReports.UI.XRTableCell tableCell22;
        private DevExpress.XtraReports.UI.XRTableCell tableCell24;
        private DevExpress.XtraReports.UI.GroupFooterBand ListaStopka;
        private DevExpress.XtraReports.UI.XRTable table3;
        private DevExpress.XtraReports.UI.XRTableRow tableRow3;
        private DevExpress.XtraReports.UI.XRTableCell tableCell18;
        private DevExpress.XtraReports.UI.XRTableCell tableCell17;
        private DevExpress.XtraReports.UI.XRTableCell tableCell15;
        private DevExpress.XtraReports.UI.XRTableCell SumaIlosc;
        private DevExpress.XtraReports.UI.XRTableCell SumaWratoscOC;
        private Soneta.Business.UI.DxReports.BusinessDataSource BusinessSourceContext;
        private DevExpress.XtraReports.UI.GroupFooterBand StopkaRaportu;
        private Soneta.Business.UI.DxReports.Controls.Footer SzablonStopkiStrony;
        private DevExpress.XtraReports.UI.GroupHeaderBand NagłówekRaportu;
        private Soneta.Business.UI.DxReports.Controls.Header SzablonNagłówkaStrony;
        private Soneta.Business.UI.DxReports.BusinessDataSource BusinessSource;
        private Soneta.Business.UI.DxReports.Components.BusinessContext BusinessContext;
        private System.Resources.ResourceManager _resources;
        public OCWgTow() {
            this.InitializeComponent();
            this.InitializeEvents();
        }
        private System.Resources.ResourceManager resources {
            get {
                if (_resources == null) {
                    this._resources = new DevExpress.XtraReports.Serialization.XRResourceManager("zsrvvgEAAACRAAAAbFN5c3RlbS5SZXNvdXJjZXMuUmVzb3VyY2VSZWFkZXIsIG1zY29ybGliLCBWZXJzaW9uPTQuMC4wLjAsIEN1bHR1cmU9bmV1dHJhbCwgUHVibGljS2V5VG9rZW49Yjc3YTVjNTYxOTM0ZTA4OSNTeXN0ZW0uUmVzb3VyY2VzLlJ1bnRpbWVSZXNvdXJjZVNldAIAAAAAAAAAAAAAAFBBRFBBRFC0AAAA");
                }
                return this._resources;
            }
        }
        private void InitializeComponent() {
            this.TopMargin = new DevExpress.XtraReports.UI.TopMarginBand();
            this.Detail = new DevExpress.XtraReports.UI.DetailBand();
            this.BottomMargin = new DevExpress.XtraReports.UI.BottomMarginBand();
            this.Powiazanie = new DevExpress.XtraReports.UI.DetailReportBand();
            this.StopkaRaportu = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.NagłówekRaportu = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.Detail1 = new DevExpress.XtraReports.UI.DetailBand();
            this.ListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.ListaStopka = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.table1 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow1 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell6 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell7 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell1 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell2 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell5 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table2 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow2 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableRow4 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell8 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell9 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell14 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell19 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell20 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell21 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell22 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell24 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table3 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow3 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell18 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell17 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell15 = new DevExpress.XtraReports.UI.XRTableCell();
            this.SumaIlosc = new DevExpress.XtraReports.UI.XRTableCell();
            this.SumaWratoscOC = new DevExpress.XtraReports.UI.XRTableCell();
            this.SzablonStopkiStrony = new Soneta.Business.UI.DxReports.Controls.Footer();
            this.SzablonNagłówkaStrony = new Soneta.Business.UI.DxReports.Controls.Header();
            this.BusinessSource = new Soneta.Business.UI.DxReports.BusinessDataSource();
            this.BusinessContext = new Soneta.Business.UI.DxReports.Components.BusinessContext();
            this.BusinessSourceContext = new Soneta.Business.UI.DxReports.BusinessDataSource();
            ((System.ComponentModel.ISupportInitialize)(this.table1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table3)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
            // 
            // TopMargin
            // 
            this.TopMargin.Dpi = 254F;
            this.TopMargin.HeightF = 200F;
            this.TopMargin.Name = "TopMargin";
            // 
            // Detail
            // 
            this.Detail.Dpi = 254F;
            this.Detail.Expanded = false;
            this.Detail.HeightF = 0F;
            this.Detail.Name = "Detail";
            // 
            // BottomMargin
            // 
            this.BottomMargin.Dpi = 254F;
            this.BottomMargin.HeightF = 200F;
            this.BottomMargin.Name = "BottomMargin";
            // 
            // Powiazanie
            // 
            this.Powiazanie.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Detail1,
                        this.ListaNagłówek,
                        this.ListaStopka});
            this.Powiazanie.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.Powiazanie.DataSource = this.BusinessSourceContext;
            this.Powiazanie.Dpi = 254F;
            this.Powiazanie.Level = 0;
            this.Powiazanie.Name = "Powiazanie";
            // 
            // StopkaRaportu
            // 
            this.StopkaRaportu.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.SzablonStopkiStrony});
            this.StopkaRaportu.Dpi = 254F;
            this.StopkaRaportu.HeightF = 51.72303F;
            this.StopkaRaportu.Name = "StopkaRaportu";
            // 
            // NagłówekRaportu
            // 
            this.NagłówekRaportu.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.SzablonNagłówkaStrony});
            this.NagłówekRaportu.Dpi = 254F;
            this.NagłówekRaportu.HeightF = 50F;
            this.NagłówekRaportu.Name = "NagłówekRaportu";
            // 
            // Detail1
            // 
            this.Detail1.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table1});
            this.Detail1.Dpi = 254F;
            this.Detail1.HeightF = 64.95834F;
            this.Detail1.Name = "Detail1";
            // 
            // ListaNagłówek
            // 
            this.ListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table2});
            this.ListaNagłówek.Dpi = 254F;
            this.ListaNagłówek.HeightF = 129.9167F;
            this.ListaNagłówek.Name = "ListaNagłówek";
            // 
            // ListaStopka
            // 
            this.ListaStopka.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table3});
            this.ListaStopka.Dpi = 254F;
            this.ListaStopka.HeightF = 64.95833F;
            this.ListaStopka.Name = "ListaStopka";
            // 
            // table1
            // 
            this.table1.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table1.BorderColor = System.Drawing.Color.DarkGray;
            this.table1.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top) 
                        | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.table1.Dpi = 254F;
            this.table1.LocationFloat = new DevExpress.Utils.PointFloat(0F, 1.335144E-05F);
            this.table1.Name = "table1";
            this.table1.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow1});
            this.table1.SizeF = new System.Drawing.SizeF(1704F, 64.95833F);
            this.table1.StylePriority.UseBorderColor = false;
            this.table1.StylePriority.UseBorders = false;
            this.table1.StylePriority.UseTextAlignment = false;
            this.table1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow1
            // 
            this.tableRow1.BorderColor = System.Drawing.Color.DarkGray;
            this.tableRow1.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableRow1.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell6,
                        this.tableCell7,
                        this.tableCell1,
                        this.tableCell2,
                        this.tableCell5});
            this.tableRow1.Dpi = 254F;
            this.tableRow1.Name = "tableRow1";
            this.tableRow1.StylePriority.UseBorderColor = false;
            this.tableRow1.StylePriority.UseBorders = false;
            this.tableRow1.StylePriority.UseTextAlignment = false;
            this.tableRow1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableRow1.Weight = 0.94427605249037838D;
            // 
            // tableCell6
            // 
            this.tableCell6.Dpi = 254F;
            this.tableCell6.Multiline = true;
            this.tableCell6.Name = "tableCell6";
            this.tableCell6.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell6.StylePriority.UsePadding = false;
            this.tableCell6.StylePriority.UseTextAlignment = false;
            this.tableCell6.Text = "[Id]";
            this.tableCell6.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell6.Weight = 0.3136122430389251D;
            // 
            // tableCell7
            // 
            this.tableCell7.Dpi = 254F;
            this.tableCell7.Multiline = true;
            this.tableCell7.Name = "tableCell7";
            this.tableCell7.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell7.StylePriority.UsePadding = false;
            this.tableCell7.StylePriority.UseTextAlignment = false;
            this.tableCell7.Text = "[Kod]";
            this.tableCell7.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell7.Weight = 1.4820504175150564D;
            // 
            // tableCell1
            // 
            this.tableCell1.Dpi = 254F;
            this.tableCell1.ExpressionBindings.AddRange(new DevExpress.XtraReports.UI.ExpressionBinding[] {
                        new DevExpress.XtraReports.UI.ExpressionBinding("BeforePrint", "Text", "[Nazwa]")});
            this.tableCell1.Multiline = true;
            this.tableCell1.Name = "tableCell1";
            this.tableCell1.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell1.StylePriority.UseTextAlignment = false;
            this.tableCell1.Text = "tableCell1";
            this.tableCell1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell1.Weight = 2.615138228510467D;
            // 
            // tableCell2
            // 
            this.tableCell2.Dpi = 254F;
            this.tableCell2.Multiline = true;
            this.tableCell2.Name = "tableCell2";
            this.tableCell2.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell2.StylePriority.UseTextAlignment = false;
            this.tableCell2.Text = "[Ilość]";
            this.tableCell2.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell2.Weight = 1.3261197676681014D;
            // 
            // tableCell5
            // 
            this.tableCell5.Dpi = 254F;
            this.tableCell5.Multiline = true;
            this.tableCell5.Name = "tableCell5";
            this.tableCell5.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell5.StylePriority.UsePadding = false;
            this.tableCell5.StylePriority.UseTextAlignment = false;
            this.tableCell5.Text = "[WartoscOC]";
            this.tableCell5.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell5.Weight = 1.2630793432674496D;
            // 
            // table2
            // 
            this.table2.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table2.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.table2.Dpi = 254F;
            this.table2.Font = new System.Drawing.Font("Calibri", 9F);
            this.table2.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table2.Name = "table2";
            this.table2.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow2,
                        this.tableRow4});
            this.table2.SizeF = new System.Drawing.SizeF(1704F, 129.9167F);
            this.table2.StylePriority.UseBorders = false;
            this.table2.StylePriority.UseFont = false;
            this.table2.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow2
            // 
            this.tableRow2.BorderColor = System.Drawing.Color.DarkGray;
            this.tableRow2.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top) 
                        | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableRow2.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell8,
                        this.tableCell9,
                        this.tableCell14});
            this.tableRow2.Dpi = 254F;
            this.tableRow2.Name = "tableRow2";
            this.tableRow2.StylePriority.UseBorderColor = false;
            this.tableRow2.StylePriority.UseBorders = false;
            this.tableRow2.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableRow2.Weight = 0.94427605249037838D;
            // 
            // tableRow4
            // 
            this.tableRow4.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell19,
                        this.tableCell20,
                        this.tableCell21,
                        this.tableCell22,
                        this.tableCell24});
            this.tableRow4.Dpi = 254F;
            this.tableRow4.Name = "tableRow4";
            this.tableRow4.Weight = 0.94427605249037838D;
            // 
            // tableCell8
            // 
            this.tableCell8.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top) 
                        | DevExpress.XtraPrinting.BorderSide.Right)));
            this.tableCell8.Dpi = 254F;
            this.tableCell8.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell8.Multiline = true;
            this.tableCell8.Name = "tableCell8";
            this.tableCell8.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell8.StylePriority.UseBorders = false;
            this.tableCell8.StylePriority.UseFont = false;
            this.tableCell8.Text = "Lp.";
            this.tableCell8.Weight = 0.3136122430389251D;
            // 
            // tableCell9
            // 
            this.tableCell9.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Top | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell9.Dpi = 254F;
            this.tableCell9.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell9.Multiline = true;
            this.tableCell9.Name = "tableCell9";
            this.tableCell9.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell9.StylePriority.UseBorders = false;
            this.tableCell9.StylePriority.UseFont = false;
            this.tableCell9.StylePriority.UsePadding = false;
            this.tableCell9.Text = "Towar";
            this.tableCell9.Weight = 5.4233084674217551D;
            // 
            // tableCell14
            // 
            this.tableCell14.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Top | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell14.Dpi = 254F;
            this.tableCell14.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell14.Multiline = true;
            this.tableCell14.Name = "tableCell14";
            this.tableCell14.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell14.StylePriority.UseBorders = false;
            this.tableCell14.StylePriority.UseFont = false;
            this.tableCell14.Text = "Wartość OC";
            this.tableCell14.Weight = 1.2630792895393197D;
            // 
            // tableCell19
            // 
            this.tableCell19.BorderColor = System.Drawing.Color.DarkGray;
            this.tableCell19.Borders = ((DevExpress.XtraPrinting.BorderSide)((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)));
            this.tableCell19.Dpi = 254F;
            this.tableCell19.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell19.Multiline = true;
            this.tableCell19.Name = "tableCell19";
            this.tableCell19.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell19.StylePriority.UseBorderColor = false;
            this.tableCell19.StylePriority.UseBorders = false;
            this.tableCell19.StylePriority.UseFont = false;
            this.tableCell19.StylePriority.UsePadding = false;
            this.tableCell19.Weight = 0.3136122430389251D;
            // 
            // tableCell20
            // 
            this.tableCell20.BorderColor = System.Drawing.Color.DarkGray;
            this.tableCell20.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top) 
                        | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell20.Dpi = 254F;
            this.tableCell20.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell20.Multiline = true;
            this.tableCell20.Name = "tableCell20";
            this.tableCell20.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell20.StylePriority.UseBorderColor = false;
            this.tableCell20.StylePriority.UseBorders = false;
            this.tableCell20.StylePriority.UseFont = false;
            this.tableCell20.StylePriority.UsePadding = false;
            this.tableCell20.Text = "Kod";
            this.tableCell20.Weight = 1.4820504175150564D;
            // 
            // tableCell21
            // 
            this.tableCell21.BorderColor = System.Drawing.Color.DarkGray;
            this.tableCell21.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Top | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell21.Dpi = 254F;
            this.tableCell21.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell21.Multiline = true;
            this.tableCell21.Name = "tableCell21";
            this.tableCell21.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell21.StylePriority.UseBorderColor = false;
            this.tableCell21.StylePriority.UseBorders = false;
            this.tableCell21.StylePriority.UseFont = false;
            this.tableCell21.StylePriority.UsePadding = false;
            this.tableCell21.Text = "Nazwa";
            this.tableCell21.Weight = 2.6151382911932859D;
            // 
            // tableCell22
            // 
            this.tableCell22.BorderColor = System.Drawing.Color.DarkGray;
            this.tableCell22.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Top | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell22.Dpi = 254F;
            this.tableCell22.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell22.Multiline = true;
            this.tableCell22.Name = "tableCell22";
            this.tableCell22.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell22.StylePriority.UseBorderColor = false;
            this.tableCell22.StylePriority.UseBorders = false;
            this.tableCell22.StylePriority.UseFont = false;
            this.tableCell22.StylePriority.UsePadding = false;
            this.tableCell22.Text = "Ilość";
            this.tableCell22.Weight = 1.3261197049852824D;
            // 
            // tableCell24
            // 
            this.tableCell24.BorderColor = System.Drawing.Color.DarkGray;
            this.tableCell24.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Top | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell24.Dpi = 254F;
            this.tableCell24.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell24.Multiline = true;
            this.tableCell24.Name = "tableCell24";
            this.tableCell24.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell24.StylePriority.UseBorderColor = false;
            this.tableCell24.StylePriority.UseBorders = false;
            this.tableCell24.StylePriority.UseFont = false;
            this.tableCell24.StylePriority.UsePadding = false;
            this.tableCell24.Weight = 1.2630793432674496D;
            // 
            // table3
            // 
            this.table3.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table3.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.table3.Dpi = 254F;
            this.table3.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table3.Name = "table3";
            this.table3.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow3});
            this.table3.SizeF = new System.Drawing.SizeF(1704F, 64.95833F);
            this.table3.StylePriority.UseBorders = false;
            this.table3.StylePriority.UseTextAlignment = false;
            this.table3.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow3
            // 
            this.tableRow3.BorderColor = System.Drawing.Color.DarkGray;
            this.tableRow3.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableRow3.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell18,
                        this.tableCell17,
                        this.tableCell15,
                        this.SumaIlosc,
                        this.SumaWratoscOC});
            this.tableRow3.Dpi = 254F;
            this.tableRow3.Name = "tableRow3";
            this.tableRow3.StylePriority.UseBorderColor = false;
            this.tableRow3.StylePriority.UseBorders = false;
            this.tableRow3.StylePriority.UseTextAlignment = false;
            this.tableRow3.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableRow3.Weight = 0.94427605249037838D;
            // 
            // tableCell18
            // 
            this.tableCell18.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell18.Dpi = 254F;
            this.tableCell18.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell18.Multiline = true;
            this.tableCell18.Name = "tableCell18";
            this.tableCell18.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell18.StylePriority.UseBorders = false;
            this.tableCell18.StylePriority.UseFont = false;
            this.tableCell18.StylePriority.UsePadding = false;
            this.tableCell18.Weight = 0.51842002087496875D;
            // 
            // tableCell17
            // 
            this.tableCell17.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell17.Dpi = 254F;
            this.tableCell17.Multiline = true;
            this.tableCell17.Name = "tableCell17";
            this.tableCell17.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell17.StylePriority.UseBorders = false;
            this.tableCell17.Weight = 2.4499191477921896D;
            // 
            // tableCell15
            // 
            this.tableCell15.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.tableCell15.Dpi = 254F;
            this.tableCell15.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.tableCell15.Multiline = true;
            this.tableCell15.Name = "tableCell15";
            this.tableCell15.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.tableCell15.StylePriority.UseBorders = false;
            this.tableCell15.StylePriority.UseFont = false;
            this.tableCell15.StylePriority.UsePadding = false;
            this.tableCell15.Text = "Suma:";
            this.tableCell15.Weight = 4.3229824030072921D;
            // 
            // SumaIlosc
            // 
            this.SumaIlosc.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.SumaIlosc.Dpi = 254F;
            this.SumaIlosc.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.SumaIlosc.Multiline = true;
            this.SumaIlosc.Name = "SumaIlosc";
            this.SumaIlosc.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.SumaIlosc.StylePriority.UseBorders = false;
            this.SumaIlosc.StylePriority.UseFont = false;
            this.SumaIlosc.StylePriority.UseTextAlignment = false;
            this.SumaIlosc.Text = "Suma Ilosc";
            this.SumaIlosc.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.SumaIlosc.Weight = 2.1921594623147986D;
            // 
            // SumaWratoscOC
            // 
            this.SumaWratoscOC.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right) 
                        | DevExpress.XtraPrinting.BorderSide.Bottom)));
            this.SumaWratoscOC.Dpi = 254F;
            this.SumaWratoscOC.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.SumaWratoscOC.Multiline = true;
            this.SumaWratoscOC.Name = "SumaWratoscOC";
            this.SumaWratoscOC.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.SumaWratoscOC.StylePriority.UseBorders = false;
            this.SumaWratoscOC.StylePriority.UseFont = false;
            this.SumaWratoscOC.StylePriority.UsePadding = false;
            this.SumaWratoscOC.StylePriority.UseTextAlignment = false;
            this.SumaWratoscOC.Text = "Suma Wratosc OC";
            this.SumaWratoscOC.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.SumaWratoscOC.Weight = 2.0879469933950952D;
            // 
            // SzablonStopkiStrony
            // 
            this.SzablonStopkiStrony.Dpi = 254F;
            this.SzablonStopkiStrony.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.SzablonStopkiStrony.Name = "SzablonStopkiStrony";
            this.SzablonStopkiStrony.ReportSourceName = "stopka";
            this.SzablonStopkiStrony.RunningBand = "NagłówekRaportu";
            this.SzablonStopkiStrony.SizeF = new System.Drawing.SizeF(1704F, 51.72303F);
            // 
            // SzablonNagłówkaStrony
            // 
            this.SzablonNagłówkaStrony.Dpi = 254F;
            this.SzablonNagłówkaStrony.FiltersDescription = null;
            this.SzablonNagłówkaStrony.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.SzablonNagłówkaStrony.Name = "SzablonNagłówkaStrony";
            this.SzablonNagłówkaStrony.ParametersDescription = null;
            this.SzablonNagłówkaStrony.ReportSourceName = "nagłówek - lista";
            this.SzablonNagłówkaStrony.SizeF = new System.Drawing.SizeF(1704F, 50F);
            this.SzablonNagłówkaStrony.Title = null;
            // 
            // BusinessSource
            // 
            this.BusinessSource.DataKind = Soneta.Business.UI.DxReports.BusinessDataKind.CurrentList;
            this.BusinessSource.DesignDataTypeName = "DokumentHandlowy";
            this.BusinessSource.Name = "BusinessSource";
            // 
            // BusinessContext
            // 
            this.BusinessContext.Name = "BusinessContext";
            this.BusinessContext.StylesSource = "standardowy";
            // 
            // BusinessSourceContext
            // 
            this.BusinessSourceContext.DataKind = Soneta.Business.UI.DxReports.BusinessDataKind.Context;
            this.BusinessSourceContext.Name = "BusinessSourceContext";
            // 
            // OCWgTow
            // 
            this.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.TopMargin,
                        this.Detail,
                        this.BottomMargin,
                        this.Powiazanie,
                        this.StopkaRaportu,
                        this.NagłówekRaportu});
            this.ComponentStorage.AddRange(new System.ComponentModel.IComponent[] {
                        this.BusinessSource,
                        this.BusinessContext,
                        this.BusinessSourceContext});
            this.DataSource = this.BusinessSourceContext;
            this.DesignerOptions.ShowExportWarnings = false;
            this.DisplayName = "SprzedazTowarowIUslugWgPozycji";
            this.Dpi = 254F;
            this.Font = new System.Drawing.Font("Calibri", 9F);
            this.Margins = new System.Drawing.Printing.Margins(198, 198, 200, 200);
            this.Name = "OCWgTow";
            this.PageHeight = 2970;
            this.PageWidth = 2100;
            this.PaperKind = System.Drawing.Printing.PaperKind.A4;
            this.ReportUnit = DevExpress.XtraReports.UI.ReportUnit.TenthsOfAMillimeter;
            this.SnapGridSize = 25F;
            this.Version = "18.1";
            this.Watermark.ShowBehind = false;
            ((System.ComponentModel.ISupportInitialize)(this.table1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table3)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this)).EndInit();
        }

        #endregion
    }
}
